@@ -1,7 +1,7 @@
 import pytest
 
 
-@pytest.fixture
+@pytest.fixture(scope="session")
 def hub(hub):
     hub.pop.sub.add(dyne_name="grains")
     hub.pop.sub.add(dyne_name="exec")
@@ -9,4 +9,4 @@ def hub(hub):
 
     hub.grains.init.standalone()
 
-    return hub
+    yield hub
